@@ -3,6 +3,7 @@ monkey.patch_all()
 import logging
 import click
 import sys
+import os.path
 
 from .config import Config
 
@@ -61,13 +62,13 @@ def topology(config, dotfile):
                 print >>f, "task_{0} -> topic_{1}".format(task.name, s)
 
         for topic in topics:
-            print >>f, "topic_{0} [label=\"{0}\", tooltip=\"{0} topic\", shape=ellipse, style=dashed]".format(
-                topic)
+            print >>f, "topic_{0} [label=\"{0}\", tooltip=\"{1}\", shape=ellipse, style=dashed]".format(
+                topic, getattr(topic, '__doc__', topic + ' topic'))
 
         print >>f, "}"
 
     click.echo(
-        "Done. You can run `dot {0}  -Tsvg -o {0}.svg` to convert it to SVG.".format(dotfile))
+        "Done. You can run `dot {0}  -Tsvg -o {1}.svg` to convert it to SVG.".format(dotfile, os.path.splitext(dotfile)[0]))
 
 
 @main.command()
