@@ -2,6 +2,7 @@ import logging
 import gevent
 from kafka import KafkaClient
 
+from .const import SOCKET_TIMEOUT
 from .task import Task
 
 logger = logging.getLogger('pymza.container')
@@ -12,7 +13,7 @@ class TaskContainer(object):
     def __init__(self, kafka_hosts, tasks, state_manager, repo):
         self.tasks = tasks
         self.state_manager = state_manager
-        self.kafka = KafkaClient(kafka_hosts)
+        self.kafka = KafkaClient(kafka_hosts, timeout=SOCKET_TIMEOUT)
         self.repo = repo
 
     def run(self):
