@@ -9,6 +9,11 @@ class _BaseOffsetTracker(object):
     def set(self, topic, partition, offset):
         raise NotImplementedError()
 
+    def force_set(self, topic, partition, offset):
+        if not self.is_modified:
+            self.is_modified = self._offsets.get((topic, partition)) != offset
+        self._offsets[(topic, partition)] = offset
+
     def __iter__(self):
         return iter(self._offsets.items())
 
@@ -21,10 +26,7 @@ class _BaseOffsetTracker(object):
 
 class SimpleOffsetTracker(_BaseOffsetTracker):
     def set(self, topic, partition, offset):
-        if not self.is_modified:
-            self.is_modified = self._offsets.get((topic, partition)) != offset
-        self._offsets[(topic, partition)] = offset
-
+        self.force_set(topic, partition, offset)
 
 class WindowedOffsetTracker(_BaseOffsetTracker):
     def __init__(self):
